@@ -1,7 +1,7 @@
 import os
 from django.db import models
 
-class Venue(models.model):
+class Venue(models.Model):
     """A backstage Venue is a specific local install of backstage."""
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
